@@ -298,7 +298,7 @@ zenity_tree (ZenityData *data, ZenityTreeData *tree_data)
     return;
   }
         
-  separator = g_strdup (tree_data->separator);
+  separator = g_strcompress (tree_data->separator);
 
   n_columns = g_slist_length (tree_data->columns);
 
@@ -480,6 +480,9 @@ zenity_tree (ZenityData *data, ZenityTreeData *tree_data)
 
   gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (tree_view), TRUE);
 
+  if (tree_data->hide_header)
+    gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (tree_view), FALSE);
+
   if (tree_data->radiobox || tree_data->checkbox) {
     if (tree_data->data && *tree_data->data)
       zenity_tree_fill_entries (GTK_TREE_VIEW (tree_view), tree_data->data, n_columns, TRUE, tree_data->editable);
